==> qtjambi-charts-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCharts/QHorizontalStackedBarSeries_shell.h <==
#ifndef QHORIZONTALSTACKEDBARSERIES_SHELL_H
#define QHORIZONTALSTACKEDBARSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qhorizontalstackedbarseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QHorizontalStackedBarSeries_shell : public QHorizontalStackedBarSeries, public QtJambiShellInterface
{
public:
    QHorizontalStackedBarSeries_shell(QObject* parent0 = nullptr);
    ~QHorizontalStackedBarSeries_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHorizontalStackedBarSeries_access : public QHorizontalStackedBarSeries
{
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHORIZONTALSTACKEDBARSERIES_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiCharts/QHorizontalStackedBarSeries_shell.h <==
#ifndef QHORIZONTALSTACKEDBARSERIES_SHELL_H
#define QHORIZONTALSTACKEDBARSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qhorizontalstackedbarseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QHorizontalStackedBarSeries_shell : public QHorizontalStackedBarSeries, public QtJambiShellInterface
{
public:
    QHorizontalStackedBarSeries_shell(QObject* parent0 = nullptr);
    ~QHorizontalStackedBarSeries_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QHorizontalStackedBarSeries_mshell;
    friend class QHorizontalStackedBarSeries_oshell;
};


class QHorizontalStackedBarSeries_mshell : public QHorizontalStackedBarSeries_shell
{
public:
    using QHorizontalStackedBarSeries_shell::QHorizontalStackedBarSeries_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QHorizontalStackedBarSeries_oshell : public QHorizontalStackedBarSeries_mshell
{
public:
    using QHorizontalStackedBarSeries_mshell::QHorizontalStackedBarSeries_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHorizontalStackedBarSeries_access : public QHorizontalStackedBarSeries
{
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHORIZONTALSTACKEDBARSERIES_SHELL_H
